API
===

This is the |lexor_ver| API documentation, autogenerated from the
source code.


lexor
-----

.. toctree::

    lexor <lexor>

lexor.core
----------

.. toctree::

    lexor.core <lexor.core>
    lexor.core.node <lexor.core.node>
    lexor.core.elements <lexor.core.elements>
    lexor.core.parser <lexor.core.parser>
    lexor.core.converter <lexor.core.converter>
    lexor.core.writer <lexor.core.writer>
    lexor.core.selector <lexor.core.selector>

lexor.commands
--------------

.. toctree::

    lexor.command <lexor.command>
    lexor.command.config <lexor.command.config>
    lexor.command.defaults <lexor.command.defaults>
    lexor.command.dist <lexor.command.dist>
    lexor.command.develop <lexor.command.develop>
    lexor.command.document <lexor.command.document>
    lexor.command.edit <lexor.command.edit>
    lexor.command.install <lexor.command.install>
    lexor.command.lang <lexor.command.lang>
    lexor.command.paste <lexor.command.paste>
    lexor.command.test <lexor.command.test>
    lexor.command.to <lexor.command.to>
